@@ -359,7 +359,6 @@ public:
                 i += c->ptn[i] + 1;
             }
         } else {
-            assert(c->vertex_to_col[c->lab[init_color_class]] == init_color_class);
             cell_todo.add_cell(&queue_pointer, init_color_class);
         }
         int its = 0;
@@ -628,6 +627,7 @@ public:
                 if(c->cells == g->v_size) {
                     color_class_splits.reset();
                     cell_todo.reset(&queue_pointer);
+                    assert(c->check());
                     // assert(assert_is_equitable(g, c));
                     return true;
                 }
@@ -656,6 +656,7 @@ public:
             }
         }
 
+        assert(c->check());
         // assert(assert_is_equitable(g, c));
         return true;
     }
@@ -1352,17 +1353,12 @@ private:
             const int deg0_col_sz = (c->ptn[deg0_col] + 1) - deg1_col_sz;
             const int deg1_col    = deg0_col + deg0_col_sz;
 
-            assert(c->vertex_to_col[c->lab[deg0_col]] == deg0_col);
-
             // no split? done...
             if(deg0_col == deg1_col) {
                 neighbours.set(deg1_col, -1);
-                assert(c->vertex_to_col[c->lab[deg0_col]] == deg0_col);
                 continue;
             }
 
-            assert(deg0_col_sz + deg1_col_sz - 1 == c->ptn[deg0_col]);
-
             // set ptn
             c->ptn[deg0_col]     = deg0_col_sz - 1;
             c->ptn[deg1_col]     = deg1_col_sz - 1;
@@ -1371,11 +1367,7 @@ private:
             deg1_write_pos = deg1_col;
             deg1_read_pos  = neighbours.get(deg0_col) - 1;
 
-            //c->vertex_to_col[c->lab[deg1_col]] = deg1_col;
-
             // rearrange vertices of deg1 to the back of deg0 color
-            assert(deg1_read_pos >= deg0_col);
-
             while(deg1_read_pos >= deg0_col) {
                 const int v             = scratch[deg1_read_pos];
                 const int vertex_at_pos = c->lab[deg1_write_pos];
@@ -1384,7 +1376,6 @@ private:
                 c->lab[deg1_write_pos]          = v;
                 c->vertex_to_lab[v]             = deg1_write_pos;
                 c->vertex_to_col[v]             = deg1_col;
-
                 c->lab[lab_pos]                 = vertex_at_pos;
                 c->vertex_to_lab[vertex_at_pos] = lab_pos;
 
@@ -1392,9 +1383,6 @@ private:
                 deg1_read_pos--;
             }
 
-            assert(c->vertex_to_col[c->lab[deg0_col]] == deg0_col);
-            assert(c->vertex_to_col[c->lab[deg1_col]] == deg1_col);
-
             // add new classes to color_class_split_worklist
             const bool leq = deg1_col_sz > deg0_col_sz;
             color_class_split_worklist->push_back(std::pair<std::pair<int, int>, bool>(
